Documentation
¶
Index ¶
Constants ¶
const ( // PictureDir - save pictures file PictureDir = "picture" // VideoDir - save videos file VideoDir = "video" // OtherDir - files other than video and picture OtherDir = "other" //FileUploadDir - the root directory of the upload files FileUploadDir = "./pkg/upload/files" // FileKey - key of the file FileKey = "file" )
Variables ¶
This section is empty.
Functions ¶
func CheckDir ¶
CheckDir Verify directory existence, if directory dosen't exists then create it Stat returns a FileInfo describing the named file. IsNotExist if file or directory not exists return true MkdirAll creates a directory named path
func ClassifyBySuffix ¶
ClassifyBySuffix - return "pictrue", "vedio", "other"
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.